@@ -484,7 +484,7 @@ class B_Trainer:
                     pass
 
     def _train_once(self, epoch, epochs):
-        bar = B_Tqdm(total=len(self.train_loader))
+        bar = B_Tqdm(range=len(self.train_loader))
         current_lr = self.optimizer.param_groups[0]['lr']
 
         self.model.train()
